import {
  select,
  json,
  csv,
  geoPath,
  geoAlbersUsa,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';

const svg = select('svg');
//The geoMercator() function in d3.js is used 
//to draw The spherical Mercator projection.
const projection = geoMercator()
  .translate([-800, 590]) // position
  .scale([850]); // zoom

// given a JSON geometry object, to generates an SVG path
const pathGenerator = geoPath().projection(projection);

//Array of ten categorical colors which is returned as RGB hexadecimal strings. 
const colorScale = scaleOrdinal(schemeCategory10);

//loading data
json('https://gist.githubusercontent.com/Eshwarreddyt/500e24b0f82c85f0c4e161ddb9aa5f70/raw/544a6f936bdba7dec4094e953a3acdf6b2396426/indiamap.json'
).then((data) => {
  //extracting states data
  const countryShapes = feature(
    data,
    data.objects.IND_adm1
  );
  
countryShapes.features.shift()

	//Renders the path to a Canvas by appending path 
  //generated by pathgenerator to svg
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'india')
    .attr('fill', (d) => colorScale(d.properties.NAME_1))
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text((d) => d.properties.NAME_1);

});